<?php
/**
 * Testimonial Carousel widget.
 *
 * @package Travel_Eye
 */

class Travel_Eye_Testimonial_Carousel_Widget extends SiteOrigin_Widget {

	function __construct() {

		parent::__construct(
			'travel-eye-testimonial-carousel',
			__( 'Travel Eye: Testimonial Carousel', 'travel-eye' ),
			array(
				'description' => __( 'Displays testimonials carousel', 'travel-eye' ),
			),
			array(),
			array(
				'title' => array(
					'type'  => 'text',
					'label' => __( 'Title', 'travel-eye' ),
				),
				'sub_title' => array(
					'type' => 'text',
					'label' => __( 'Sub Title', 'travel-eye' ),
				),
				'testimonials' => array(
					'type'       => 'repeater',
					'label'      => __( 'Testimonials', 'travel-eye' ),
					'item_name'  => __( 'Testimonial', 'travel-eye' ),
					'item_label' => array(
						'selector'     => "[id*='testimonials-full_name']",
						'update_event' => 'change',
						'value_method' => 'val',
					),
					'fields' => array(
						'full_name' => array(
							'type'  => 'text',
							'label' => __( 'Full Name', 'travel-eye' ),
						),
						'position' => array(
							'type'  => 'text',
							'label' => __( 'Position', 'travel-eye' ),
						),
						'message' => array(
							'type'  => 'textarea',
							'label' => __( 'Message', 'travel-eye' ),
						),
						'profile_picture' => array(
							'type'     => 'media',
							'library'  => 'image',
							'label'    => __( 'Image', 'travel-eye' ),
							'fallback' => true,
						),
					),
				),
				'settings_color' => array(
					'type'   => 'section',
					'label'  => __( 'Color Settings', 'travel-eye' ),
					'hide' => true,
					'fields' => array(
						'color_widget_title' => array(
							'type'    => 'color',
							'label'   => __( 'Widget Title Color', 'travel-eye' ),
							'default' => '#626262',
							),
						'color_widget_sub_title' => array(
							'type'    => 'color',
							'label'   => __( 'Widget Subtitle Color', 'travel-eye' ),
							'default' => '#313131',
						),
						'color_arrow_icon' => array(
							'type'    => 'color',
							'label'   => __( 'Arrow Icon Color', 'travel-eye' ),
							'default' => '#fff',
						),
						'color_arrow_icon_background' => array(
							'type'    => 'color',
							'label'   => __( 'Arrow Icon Background Color', 'travel-eye' ),
							'default' => '#DD3333',
						),
						'color_arrow_icon_background_hover' => array(
							'type'    => 'color',
							'label'   => __( 'Arrow Icon Background Hover Color', 'travel-eye' ),
							'default' => '#DD3333',
						),
					),
				),
			)
		);
	}

	function get_template_name( $instance ) {
		return 'default';
	}

	function get_style_name( $instance ) {
		return 'default';
	}

	function get_less_variables( $instance ) {

		$less_vars = array();
		if ( ! empty( $instance['settings_color']['color_widget_title'] ) ) {
			$less_vars['color_widget_title'] = $instance['settings_color']['color_widget_title'];
		}
		if ( ! empty( $instance['settings_color']['color_widget_sub_title'] ) ) {
			$less_vars['color_widget_sub_title'] = $instance['settings_color']['color_widget_sub_title'];
		}
		if ( ! empty( $instance['settings_color']['color_arrow_icon'] ) ) {
			$less_vars['color_arrow_icon'] = $instance['settings_color']['color_arrow_icon'];
		}
		if ( ! empty( $instance['settings_color']['color_arrow_icon_background'] ) ) {
			$less_vars['color_arrow_icon_background'] = $instance['settings_color']['color_arrow_icon_background'];
		}
		if ( ! empty( $instance['settings_color']['color_arrow_icon_background_hover'] ) ) {
			$less_vars['color_arrow_icon_background_hover'] = $instance['settings_color']['color_arrow_icon_background_hover'];
		}
		return $less_vars;

	}

	function initialize() {
		$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

		$this->register_frontend_styles(
			array(
				array(
					'slick-css',
					get_template_directory_uri() . '/third-party/slick/slick' . $min . '.css',
					array(),
					'1.5.9',
				),
			)
		);

		$this->register_frontend_scripts(
			array(
				array(
					'slick-js',
					get_template_directory_uri() . '/third-party/slick/slick' . $min . '.js',
					array( 'jquery' ),
					'1.5.9',
					true,
				),
				array(
					'travel-eye-testimonial-carousel-custom',
					get_template_directory_uri() . '/inc/so-widgets/testimonial-carousel/js/custom.js',
					array( 'jquery', 'slick-js' ),
					'1.0.0',
					true,
				),
			)
		);

	}
}

siteorigin_widget_register( 'travel-eye-testimonial-carousel', __FILE__, 'Travel_Eye_Testimonial_Carousel_Widget' );
